#
# spec file for package system-config-printer
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           system-config-printer
License:        GPLv2+
Group:          Hardware/Printing
Version:        1.2.5
Release:        5.10.1
Summary:        A printer administration tool
Url:            http://cyberelk.net/tim/software/system-config-printer/
Source0:        http://cyberelk.net/tim/data/system-config-printer/1.0.x/system-config-printer-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE system-config-printer-icon-brp-friendly.patch vuntz@novell.com -- brp checks don't like the printer icon name, so we have to use something else
Patch13:        system-config-printer-icon-brp-friendly.patch
# PATCH-FIX-OPENSUSE system-config-printer-firewall-menu.patch vuntz@novell.com -- Fix string to mention correct path in menus to firewall tool
Patch18:        system-config-printer-firewall-menu.patch
# PATCH-FIX-OPENSUSE system-config-printer-no-openprinting.patch bnc#733542 vuntz@opensuse.org -- Disable feature that downloads ppd from openprinting.org
Patch19:        system-config-printer-no-openprinting.patch
# PATCH-FIX-UPSTREAM system-config-printer-subprocess-no-shell.patch bnc#735322 vuntz@opensuse.org -- Always use sequences for subprocess to avoid escaping issues; sent upstream by mail
Patch20:        system-config-printer-subprocess-no-shell.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Obsoletes:      gnome-cups-manager <= 0.33
BuildRequires:  cups-devel
# For directory ownership
BuildRequires:  dbus-1
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  glib2-devel
BuildRequires:  gnome-icon-theme
BuildRequires:  gnome-patch-translation
# For directory ownership
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  libudev-devel
BuildRequires:  libusb-compat-devel
BuildRequires:  python-devel
BuildRequires:  python-xml
BuildRequires:  update-desktop-files
BuildRequires:  xmlto
Requires:       cups
Requires:       dbus-1-x11
Requires:       dbus-1-python
Requires:       desktop-file-utils
Requires:       python-cups
Requires:       python-cupshelpers
Requires:       python-gnome
Requires:       python-gobject2
Requires:       python-gtk
Requires:       python-notify
Requires:       python-smbc
Recommends:     %{name}-lang
Recommends:     cups-pk-helper
Recommends:     udev-configure-printer
%py_requires
%if %suse_version <= 1110
%define python_sitelib %{py_sitedir}
%endif

%description
system-config-printer is a graphical user interface that allows the
user to configure a CUPS print server.

%package -n python-cupshelpers
License:        GPLv2+
Summary:        High-level Python Bindings for CUPS
Group:          Hardware/Printing
Requires:       python-cups
%py_requires

%description -n python-cupshelpers
This package contains high-level python bindings for CUPS, and can be
used on top of python-cups.

%package -n udev-configure-printer
License:        GPLv2+
Summary:        Utility to autoconfigure printers when plugged
Group:          Hardware/Printing
Obsoletes:      cups-autoconfig <= 0.1.0
Requires:       dbus-1-python
Requires:       python-cups
Requires:       python-cupshelpers
%py_requires

%description -n udev-configure-printer
This package contains an utility that will ensure printers get
automatically configured when plugged on the computer.


%lang_package
%prep
%setup -q
gnome-patch-translation-prepare
%patch13 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1
gnome-patch-translation-update

%build
%if %suse_version > 1110
%configure \
        --with-udev-rules
%else
%configure
%endif

%install
%makeinstall udevrulesdir=/lib/udev/rules.d udevhelperdir=/lib/udev
for size in 8x8 16x16 22x22 24x24 32x32 48x48; do
	if test -f %{_datadir}/icons/gnome/$size/devices/printer.png; then
		mkdir -p $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/$size/apps
		cp -a %{_datadir}/icons/gnome/$size/devices/printer.png $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/$size/apps/%{name}.png
	fi
done
%suse_update_desktop_file print-applet
%suse_update_desktop_file system-config-printer X-SuSE-PrintingUtility X-SuSE-ControlCenter-Hardware
%suse_update_desktop_file manage-print-jobs
%fdupes $RPM_BUILD_ROOT/%{py_sitedir}
%find_lang %{name} %{?no_lang_C}

%clean
rm -rf $RPM_BUILD_ROOT

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root,-)
%doc ChangeLog COPYING README
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/newprinternotification.conf
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/printerdriversinstaller.conf
%{_bindir}/%{name}
%{_bindir}/%{name}-applet
%{_datadir}/%{name}
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/*
%{_sysconfdir}/xdg/autostart/*.desktop
%{_mandir}/man1/*

%files -n python-cupshelpers
%defattr(-,root,root,-)
%exclude %{python_sitelib}/cupshelpers/*.pyc
%{python_sitelib}/cupshelpers
%{python_sitelib}/cupshelpers*.egg-info
%if %suse_version > 1110

%files -n udev-configure-printer
%defattr(-,root,root,-)
%dir /lib/udev
%dir /lib/udev/rules.d
/lib/udev/rules.d/*.rules
/lib/udev/udev-add-printer
/lib/udev/udev-configure-printer
%endif

%files lang -f %{name}.lang

%changelog
* Tue Jan  3 2012 vuntz@opensuse.org
- Fix coding errors caught by Stephen Shaw <stshaw@suse.com> in
  system-config-printer-subprocess-no-shell.patch.
* Thu Dec  8 2011 vuntz@opensuse.org
- Add system-config-printer-subprocess-no-shell.patch: avoid
  escaping issues when running commands. Fix bnc#735322.
* Tue Dec  6 2011 vuntz@opensuse.org
- Add system-config-printer-no-openprinting.patch: this disables
  the feature where PPD drivers can be downloaded from
  OpenPrinting.org. See discussion in bnc#733542. As a side-effect,
  this fixes CVE-2011-4405.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Wed Oct 13 2010 vuntz@opensuse.org
- Update to version 1.2.5:
  + Do not accept some invalid characters in various entries.
  + Add examples of IPP URI to NewPrinterWindow (rh#575795).
  + Delete Bluetooth printer's queue when unpaired.
  + Create ~/.printer-groups.xml only when group is created.
  + Add CMD-field matching for PPDs (rh#630058).
  + Save name of PPD which matches best to the detected printer,
    not only make/model.
  + Mark more strings as translatable.
  + Fix some crashes.
  + Small improvements and fixes.
  + Updated translations.
* Tue Aug 24 2010 dimstar@opensuse.org
- Update to version 1.2.4:
  + udev helper: use CUPS defaults when connecting.
  + Blacklist certain printer state reasons (rh#520815).
  + Exclude dnssd backend from udev search.
  + Do not error out on missing firewall D-Bus service.
  + Prioritize HP's hpcups driver against HPIJS.
  + Improvements for setting up Bluetooth printers.
  + udev-configure-printer: Match usblp, libusb, HPLIP, and USB
    device file URIs.
  + Fill the queue list when clicking "Probe" in LPD printer setup
    screen.
  + Remove the ":9100" from discovered "socket://..." URIs.
  + Integration of the dnssd CUPS backend and assosiation of DNS-SD
    names and IPs.
  + When setting up a printer search for local drivers before
    searching the internet.
  + Access OpenPrinting via the web query API with redirect
    support.
  + Prioritize DNS-SD-based URIs against IP-based URIs.
  + On discovered network printers do not only cache make and model
    but also the device ID.
  + Fix recognition of remote CUPS queues when setting up an IPP
    queue.
  + Avoid connecting to cups twice in PPDsLoader.
  + Make udev-configure-printer work for Bluetooth.
  + rh#618357: Changed shebang in executables
  + Various other bug fixees.
  + Updated translations.
- Rebase system-config-printer-icon-brp-friendly.patch
* Sat Aug  7 2010 vuntz@opensuse.org
- Clean up update to 1.2.3.
- Force installation of udev rules and helpers in /lib/udev instead
  of /etc/udev, since the default is to put a binary in /etc/udev,
  which is wrong.
* Wed Jul  7 2010 dimstar@opensuse.org
- Update to version 1.2.3:
  + Add Bluetooth auto-config to udev-configure-printer.
  + Make sure automatically-created queues will work.
  + Don't add queues for Graphtec devices.
  + Use sysconfdir for udev rules.
  + UI improvements.
  + Bug fixes.
  + Updated translations
- Changes from version 1.2.2:
  + Resolve DNS-SD hostnames for physical device comparison.
  + Handle connection failures to cups better.
  + UI improvements.
  + Bug fixes.
  + Updated translations
- Changes from version 1.2.1:
  + Many improvements in check-device-ids.
  + Use cups-pk-helper method for canceling jobs.
  + Add 25%%, 50%% and 75%% level markers in the inklevel widget.
  + Improve Firewall interaction (Fedora-specific).
  + Fix a few crashes.
  + Bug fixes.
  + Updated translations
- Add glib2-devel BuildRequires.
- Rebase system-config-printer-icon-brp-friendly.patch.
* Thu Mar 18 2010 dimstar@opensuse.org
- Update to version 1.2.0:
  + The my-default-printer application has been removed.
  + Printer drivers are automatically installed when possible.
  + The basic/advanced server settings dialogs have been merged.
  + PPDs are now fetched asynchronously.
  + The job viewer has seen many improvements.
  + Updated translations.
- remove fixme regarding polkit-1: current configure would not
  even know about it.
- Rebase system-config-printer-icon-brp-friendly.patch to apply
  without fuzz.
* Sat Feb 27 2010 dimstar@opensuse.org
- Update to version 1.1.93:
  + Display a warning when the wrong IEEE 1284 ID is detected
  + rh#566938: catch RuntimeError in statereason.py when
    cupsGetPPD2 fails
  + Removed HP and Kyocera IEEE 1284 Device ID hacks
  + Increased new printer notification timeout to 20 minutes.
  + Added simple program to check IEEE 1284 Device IDs against PPDs
  + Update translations.
* Sun Feb 21 2010 dimstar@opensuse.org
- Update to version 1.1.92:
  + system-config-printer:
  - Use stock 'add' icon for new-printer button (lp#394071)
  - Use gtk.STOCK_ instead of gtk- throughout
  - Avoid clearing selecting device settings when adding a
    printer
  - Update the PolicyKit code to use the correct signature for
    DeviceGet
  - ppsloader: avoid traceback
  - Set timeout for InstallPrinterDrivers D-Bus call
  + Updated translations.
* Wed Feb 10 2010 vuntz@opensuse.org
- Update to version 1.1.91:
  + system-config-printer:
  - Make it obvious when a printer is disabled.
  - Update 'Time submitted' column when clicking Refresh in job
    viewer.
  - Fixed traceback when renaming a printer.
  - Fixed async pycups fallback again.
  - Fixed statereason localization for raw queues (rh#558156).
  - Set model for LPD queue ComboEntry.
  - Only add current device to list when all devices found
    (rh#558524).
  - When retrying authentication as another user, forbid
    PolicyKit.
  - Use tooltips in jobs treeview.
  - Avoid non-zero page sizes in SpinButton adjustments.
  - Only show jobs for selected printers in job viewer.
  - Better error handling when renaming a printer (rh#561182).
  - Troubleshooter checks local SELinux file contexts.
  - Fixed drop-down list for connection dialog.
  - Avoid crash filling makes list when no make detected
    (rh#562520).
  - Fixed automatic driver assignment via applet.
  - Minor bugfixes and HIG fixes.
  + Updated translations.
* Wed Jan 20 2010 vuntz@opensuse.org
- Update to version 1.1.90:
  + system-config-printer:
  - Parse foomatic's special DRV Device ID field (rh#550108).
  - Driver selection fixes (rh#550075).
  - Remove my-default-printer application.
  - Handle cancelJob's optional purge_job parameter in PolicyKit1
    backend.
  - Changed 'Clear job' to 'Delete job'.
  - Make sure the printer we added still exists before selecting
    it (rh#551436).
  - Set notification timeouts appropriately (rh#550829).
  - "Copy" action in context menu is now called "Duplicate".
  - Make sure there are enough ink level values (rh#541882).
  - Reinstated job completion notifications with better text.
  - Remove job attributes viewer tabs for jobs that have been
    purged.
  - Use asyncconn for canceling/deleting jobs.
  - Ability to retrieve job files which have been preserved.
  - Set D-Bus timeout when calling asynchronously.
  - Restore option values for serial device.
  - Fixed window modality and transience.
  - PrinterDriversInstaller implementation: this is a system bus
    service to install drivers via PackageKit.
  - Use asyncconn to fetch PPDs.
  - Don't rely on cups-pk-helper being around (rh#556170).
  - Make sure serial device widgets are always initialized
    (rh#556488).
  - Clean up temporary files when localizing statereason
    (rh#552768).
  - Removed support for installing HP's proprietary plug-in.
  - Fix various tracebacks (rh#550442, rh#550437, rh#553141,
    rh#554372, rh#554268, rh#555552).
  - Avoid leaking resources.
  - Code cleanups.
  - Updated translations.
  + udev-configure-printer/udev-add-printer:
  - avoid traceback when no CMD field present.
  - try to install drivers first.
- Update system-config-printer-icon-brp-friendly.patch after
  my-default-printer removal.
- Remove system-config-printer-hide-my-default-printer.patch:
  my-default-printer was removed.
* Wed Dec 23 2009 vuntz@opensuse.org
- Update to version 1.1.16:
  + system-config-printer:
  - Don't fail if smbc module is not available.
  - Don't overwrite BrowsePoll settings with basic settings
    dialog (rh #543986).
  - Fixed cupsd.conf parsing when lines begin with blanks
    (rh#544003).
  - Constraints handling fix.
  - Clear device screen each time a new dialog is presented.
  - Prefer Foomatic/hpijs to hpcups for the time being.
  - Rearchitecture code for more asynchronous code, and use it to
    fetch the device list in a safe way.
  - Adapted to new pycups API for cupsSetPasswordCB2.
  - Ignore com.apple.print.recoverable state reason.
  - Fix various tracebacks.
  + Updated translations.
* Wed Dec 16 2009 vuntz@opensuse.org
- Update to version 1.1.15:
  + system-config-printer:
  - Fix a traceback.
  - Don't update properties if apply failed (rh#542503).
- Changes from version 1.1.14:
  + system-config-printer:
  - Avoid unnecessary "publish printers" dialog.
  - Translate job-hold-until and retry-current-job values.
  - Attempt to discover whether the firewall needs adjusting.
  - Iconify jobs window into status icon.
  - Handle hpcups driver for 5400 series in test suite.
  - Added SMB support to 'Find Network Printer'.
  - Fixed device fetch when not using polkit-1.
  - Cancel PrinterFinder when new-printer dialog closes.
  - Added IPP and JetDirect support to 'Find Network Printer'.
  - Use the correct URI for probed CUPS queues.
  - Better order for network printer probes.
  - Use make-and-model to guess the PPD driver for a discovered
    printer, if no device ID is available.
  - Improve default name of printer, when the name already
    exists.
  - Auto-select raw queue correctly when changing PPD.
  - Attempt to determine make and model of network printers
    (rh#524321).
  - Don't display properties dialog for first test page
    (lp#444280).
  - Fixed visibility tracking for jobs window.
  - Strip 'zjs', 'zxs', 'pcl3' from make-and-model (rh#531048).
  - Added support for custom state reasons.
  - Catch IPP errors when updating from notified events
    (rh#530641).
  - Fail nicely if new printer is deleted during test page prompt
    (rh#533109).
  - Suggest installing foomatic-db-ppds when appropriate.
  - Install the foomatic package if foomatic-rip is missing.
  - Retry when reconnection (due to authentication) fails
    (rh#541741).
  - Various small bug and UI fixes.
  - Various code improvements.
  - Fix various tracebacks.
  + udev-configure-printer/udev-add-printer:
  - Build system fixes.
* Sat Oct 10 2009 dimstar@opensuse.org
- Update to version 1.1.13:
  + system-config-printer:
  - Use correct statereason level icon names.
  - Handle icon load failure gracefully.
  - Fix cleaning of TurboPrint PPD listings of CUPS 1.4.x.
  - Avoid error dialog after cancelling operation via PolicyKit
    dialog.
  - Fetch devices in a separate thread to avoid blocking
    (lp#516787).
  - Add polkit-1 support, and make it conditional on "configure
  - -with-polkit-1".
  - Fixed traceback with older versions of GTK+.
  - Fixed proxy authentication.
  - Allow PPD/device changes for raw queues.
  - Extended TimedOperation class to allow callbacks
  - Fixed cupspk support for DevicesGet
  - Allow parameters to cupshelpers.getDevices
  - Allow for more than one spinner task
  - Use callbacks when fetching devices
  - Fixed spinner UI bug
  - Fixed cancellation in TimedOperation class
  - Fetch network devices as soon as local devices are received
  - Make sure to cancel the fetchDevices callback when not needed
  + Updated translations.
- Rebase system-config-printer-firewall-menu.patch to apply with
  fuzz=0.
* Wed Aug 26 2009 vuntz@novell.com
- Update to version 1.1.12:
  + system-config-printer:
  - Don't get tripped up by "-" when checking for missing
    executables.
  - HP's Bluetooth printers return a model name with added "_BT"
    in their device ID.
  - Added support for localized marker names
  - Fixed parenting of WaitWindow when adding printer.
  - Don't attempt to use PolicyKit if we are root.
  - Support for cups-pk-helper's DevicesGet method.
  - Use modern gtk tooltip support.
  - Fixed typo handling exceptions from
    AdvancedServerSettingsDialog.
  - Use set_default_size instead of setting width and height
    properties.
  - Fixed missing treeview update in properties dialog.
  - Fixed identification of CUPS native gutenprint drivers.
  - Prefer native CUPS drivers to foomatic drivers.
  - Busy/ready cursor handling fixes.
  - Use separate thread for verifying IPP queue.
  - Set an appropriate status icon tooltip when configuring
    printer.
  - Fixed cupspk handling of disabling a printer.
  - Show a 'paused' emblem for disabled printers.
  - Use preferred object path for AuthenticationAgent.
  - Kill job creation times timer on the jobviewer is destroyed.
  - Only update job creation times once per minute at rest.
  - Job status icon and state reason in jobs treeview.
  - Show rejecting printers as insensitive.
  - Added experimental package tagging for PPD files.
  - Removed notification when job has completed.
  - Fixed applet traceback when printing test page.
  - Don't allow Back/Forward to lose troubleshooting diagnostic
    information.
  - Code cleanups.
  + udev-configure-printer/udev-add-printer:
  - Compare MFG and MDL case-insensitively.
  + Updated translations.
* Sat Aug  8 2009 vuntz@novell.com
- Update to version 1.1.11:
  + udev-configure-printer/udev-add-printer:
  - don't add fax queue if already present
  - don't fork if DEBUG environment variable set
  - Enable/disable queues with paired device URIs
  - use '/' as delimiter when examining device URI
  - make sure we don't configure the same printer twice
  - Don't set USB configuration in udev-configure-printer
  - Serialize CUPS-Get-Devices requests
  - Exit early in udev-configure-printer if device already mapped
    to URIs
  - don't require pycups 1.9.46 just yet
  - Fixed name uniqueness checking
  - Notify the correct printer name
  - create fax queues using prefix of printer queue
  - fixed duplicate devpath check
  - fixed removal when cupsd not running
  + system-config-printer:
  - Use case-insensitive matching when cleaning up the PPD nick
    names to get the model names for the make/model/driver list
  - Made extracting make and model from the NickName of
    TurboPrint PPDs working again
  - Made the field for freely typing in an URI actually work
  - Better method of determining current device URI
  - Printer icon should not show 'printing' when job stopped
  - Updates for hplip 3.9.6
  - Let the checks for adding a device to a physicaldevice object
    parse HPLIP URIs correctly to extract the host name/IP from
    them
  - jobviewer: notice jobs that have stopped due to backend
    errors
  - Fixed cupspk's implementation of adminGetServerSettings()
  - A warning is given that renaming destroys print job history
  - Small improvements for printer rename confirmation
  - API improvement in cupshelpers: limit job fetches
  - troubleshoot: treat http and https schemes as potential CUPS
    servers
  - Make properties dialog OK button insensitive when no changes
  - Validate BrowsePoll entries
  + Code cleanups and plug leaks.
  + Updated translations.
* Wed Aug  5 2009 vuntz@novell.com
- Fix build on 11.1 and earlier: we don't want the udev helpers
  there.
* Thu Jul 23 2009 vuntz@novell.com
- Update to version 1.1.10:
  + Support for HPLIP 3.9.6.
  + Fixed 'location' field for printers added remotely.
  + Avoid traceback when adding new printer.
  + Parse nmblookup failures correctly.
  + Avoid non-fatal traceback when adding IPP printer.
  + Make sure we find https URIs from https backend.
  + Prevent traceback on IPP notification after properties dialog
    cancelled.
  + Fixed incorrect authentication in the troubleshooter.
  + Arrows for adding and removing class members are sensitive only
    if something is selected.
  + Small fix for class members arrows: always de-sensitise buttons
    after use.
  + Another fix for selecting an added printer.
  + Spot stopped jobs with CUPS 1.4 as well.
  + Map gutenprint filenames to the package name.
  + Use gpk-install-package-name to install packages, not the PK
    D-Bus API.
  + Always update the jobviewer status icon on job events.
  + Fixed UI oddities when changing PPD/device.
  + Avoid possible traceback when receiving printer-added-events.
  + Fixed initial radio button selection for SMB authentication.
  + Make sure to URL-encode usernames and passwords correctly.
  + Don't run Properties dialog on new printer.
  + Don't mention the job number in completed jobs notification.
  + Check exit codes for child processes.
  + Removed IPP browser.
  + Improved matching of printer model names.
  + Added PIXMA comment to test suite.
  + Efficiency fixes for PPDs Device ID matching.
  + Fixed --debug option for PPDs self-test function.
  + Efficiency and readability improvements in PPDs Device ID
    matcher.
  + Avoid cups.setServer/setPort.
  + Fixed incorrect "printer not shared on server" message.
  + Drop libsexy support in favour of GTK+ 2.17's equivalent.
  + Avoid reloading all PPDs when calls to jockey fail.
  + Small speed-up (0.09s) for the case where jockey is not
    present.
  + Don't reload all PPDs if the query has already finished.
  + 75%% speed improvement in ppdMakeModelSplit().
  + New udev-based queue configuration system.
  + Improve window size.
  + Fixed hang on start-up when trying to resize the window.
  + Fixed tracebacks in cupshelpers.ppds test suite.
  + Fixed Device ID matching for HPLIP PPDs.
  + Updated translations.
- Add cups-devel, libudev-devel, libusb-compat-devel BuildRequires.
- Pass --with-udev-rules to configure.
- Package the udev helpers in udev-configure-printer. This package
  Obsoletes cups-autoconfig, since the new udev helpers now do this
  job.
- Split cupshelpers python module in python-cupshelpers package
  since it's needed by udev-configure-printer.
- Drop system-config-printer-cups-autoconfig-notifications.patch:
  we will now use the udev tool and we will receive notifications
  without this patch.
* Mon Jul 20 2009 vuntz@novell.com
- Update to version 1.1.8 (this is not a complete list of changes
  since upstream uses git, but some changes aren't listed in
  ChangeLog):
  + Set relaxed PPD conformance
  + Fixed URI parsing when verifying IPP URIs
  + Set glade's textdomain in the jobviewer (lp#341765)
  + Made hp-plugin call also working with HPLIP 3.9.2
  + Adjusted border padding for New Printer window
  + Use ValueError in PhysicalDevice to indicate device is
    different
  + Import debugprint in cupspk
  + Fixes on automatic printer model selection and suggestion of
    queue name
  + Style and efficiency improvements
  + Fixed XmlHelper crash on invalid XML file (lp#370469)
  + Clean up temporary PPD files when we're finished with them
  + Reconnect to CUPS if the connection gets lost during the
    installation of a driver from OpenPrinting
  + Scroll to new job if it was added just above the visible range
  + Use grey ink-drop when there is no marker-colors value
  + Fixed conversion from broken-down UTC time to simple UNIX time
    for held jobs
  + Track printer state changes for the printer context menu
  + Removed some stale code in cupshelpers
  + Make sure the job context menu cannot get out of date
  + Select a newly-added printer
  + Make troubleshooter work again by disabling cupspk for it
* Wed Apr 15 2009 vuntz@novell.com
- Update to version 1.1.7 (this is not a complete list of changes
  since upstream uses git, but some changes aren't listed in
  ChangeLog):
  + Prevent some tracebacks
  + Various improvements for printer model identification
  + Added support for https device URIs showing the IPP screen
  + Efficiency fixes
  + Do not use setlocale() for locale-independent
    uppercase/lowercase conversion
  + jobviewer: don't abort if we couldn't show a notification
* Sat Mar 14 2009 vuntz@novell.com
- Update to version 1.1.6 (this is not a complete list of changes
  since upstream uses git, but some changes aren't listed in
  ChangeLog):
  + Use setlocale() to save current LC_CTYPE value, not getlocale()
  + Don't try search for a model series if there are no digits in
    the model name
  + Adapted D-Bus policy file to the new D-Bus defaults
  + Better PPD fallback searching.
  + Strip " hpijs" from PPD names.
* Fri Mar  6 2009 vuntz@novell.com
- Update to version 1.1.5 (this is not a complete list of changes
  since upstream uses git, but some changes aren't listed in
  ChangeLog):
  + UI improvements in the new printer dialog.
  + Include local printer attributes in diagnostic output.
- Drop system-config-printer-bnc456110-non-blocking-probe.patch:
  fixed upstream.
- Drop system-config-printer-fix-add-printer-git051bc7f0.patch:
  fixed upstream.
* Thu Feb 26 2009 vuntz@novell.com
- Add system-config-printer-fix-add-printer-git051bc7f0.patch:
  patch from git to fix the "Add printer" dialog not working.
* Tue Feb 24 2009 vuntz@novell.com
- Add system-config-printer-bnc456110-non-blocking-probe.patch:
  make the probing code non-blocking for the UI.
  Fix bnc#456110.
* Mon Feb 23 2009 vuntz@novell.com
- Add system-config-printer-firewall-menu.patch: fix string to
  mention the correct path in menus to access the firewall tool.
  Fix bnc#442106.
- Use gnome-patch-translation for the new string.
  (Thanks to Stanislav Brabec for this)
* Sat Feb 21 2009 vuntz@novell.com
- Update to version 1.1.4 (this is not a complete list of changes
  since upstream uses git, but some changes aren't listed in
  ChangeLog):
  + Don't display status icon for completed jobs
  + Only add job to the active set if it is active; otherwise,
    remove it from the set if it is there.
  + If the emptiness of the active set has changed, update the
    status icon.
  + Handle D-Bus failures when connecting to the session bus
    (Jockey) (rh#484402)
  + Don't show wait window when adding a new printer, as that may
    require an authentication dialog and we don't want them
    competing for focus (rh#484960)
  + Don't grab keyboard and pointer when displaying authentication
    dialog. Instead let the window manager prevent keyboard input
    accidentally going to the wrong window.
  + Don't display a notification when authentication is required,
    just go straight to the authentication dialog. Don't grab
    keyboard and pointer for that dialog and instead let the window
    manager prevent keyboard input accidentally going to the wrong
    window.
  + Otptions: Check constraints in reverse as well, so that
    constraint checking is symmetrical.
  + Don't allow PPD changes when there are conflicts
  + Support for auto-detection of printers vis hal-cups-utils
    without hal-cups-utils creating a queue, especially if there is
    no driver specifically assigned to the detected printer.
  + Skip selection of manufacturer, model, and driver in the
    new-printer wizard if an exact driver match has been found.
  + Added functionality to automatically recognize whether the
    proprietary plug-in of HPLIP is useful or even required and to
    ask the user whether he want to download and install it.
  + Fixed "hp-info" calls: There should be no space between "-d"
    and the "URI" to work around HPLIP option parsing bug.
  + Return None if the "fax-type" is 0, this means that fax is not
    available on the given printer.
  + Fixed switch between the notification for the case that a queue
    got created and the case that no queue got created.
  + Perform lowercase operations in locale-independent manner.
  + Merge cups-pk-helper branch.
  + Updated translations.
- Split cups-pk-helper and pysmbc in their own packages.
- Remove BuildRequires because of the split: PolicyKit-devel,
  cups-devel, dbus-1-glib-devel, epydoc, gtk2-devel,
  libsmbclient-devel.
- Remove BuildRequires: gettext-devel.
- Add Requires on python-smbc.
- Add Recommends on cups-pk-helper.
- Drop system-config-printer-policykit.patch: accepted upstream!
- Drop system-config-printer-more-checks.patch: upstream improved
  the PolicyKit support to not require this.
- Drop system-config-printer-python-prefix.patch: was needed only
  for pysmbc.
- Do not call autoreconf anymore.
* Thu Feb  5 2009 vuntz@novell.com
- Drop system-config-printer-install-python.patch after discussion
  on opensuse-packaging. Update the file list accordingly.
* Thu Feb  5 2009 vuntz@novell.com
- Update to version 1.1.3:
  + Refresh server settings when the advanced server settings
    dialog has finished.
  + Better default height for jobs window.
  + Put waiting cursor when filling make/model lists.
  + Find parent window to set Conflicts dialogtransient for.
  + Various fixes for conflicts button.
  + Fix the potential dbus security issue with send_interface
  + Fixed traceback while fetching hpfax device ID (lp#321139)
  + Use authenticated	connection, except when printing the test
    page.
  + Don't make the troubleshooter window transient for the main
    window (rh#481505)
- Drop system-config-printer-bnc468379-dbus-send-dest.patch: fixed
  upstream.
- Respin system-config-printer-install-python.patch.
* Sun Feb  1 2009 mboman@suse.de
- Update to version 1.1.2:
  + Prevent traceback.
  + Collapse/expand device rows on activation.
  + Avoid traceback with raw queues.
  + Added accessibility relations
  + Handle notification closure for re-connected printers correctly.
  + Advertise correct defaults for page-left, page-right, page-top and
    page-bottom job options (rh#468553).
* Tue Jan 27 2009 vuntz@novell.com
- Update to pysmbc 1.0.6 (no NEWS included).
- Drop pysmbc-bnc433994-crash.patch: fixed upstream.
- Really drop system-config-printer-prefill-name-descr.patch.
- Minor cleanup of the file list.
- Use system-config-printer-policykit.patch from my git tree.
- Add cups-pk-helper-bnc468389-dbus-send-dest.patch and
  system-config-printer-bnc468379-dbus-send-dest.patch to add
  send_destination in the dbus policies. Fix bnc#468379 and
  bnc#468387.
* Sun Jan 11 2009 mboman@suse.de
- Fix a small issue in system-config-printer-policykit.patch
* Mon Jan  5 2009 mboman@suse.de
- Update to version 1.1.1:
  + Too many fixes/changes. Please see Changelog for full details.
- Remove system-config-printer-git1.0.x.patch and
  system-config-printer-git1.0.x-po.patch due to version upgrade
- Remove system-config-printer-remove-redhat-base.patch. Fixed upstream
- Remove system-config-printer-prefill-name-descr.patch. Fixed upstream
- Remove pycups package, already in the distro as python-cups
- Respin system-config-printer-install-python.patch
- Respin system-config-printer-policykit.patch
* Tue Dec 16 2008 coolo@suse.de
- require lang subpackage
* Fri Nov 21 2008 vuntz@novell.com
- Update cups-pk-helper to 0.0.3 (there is no upstream project, but
  I still version the code):
  + make various checks to be sure that the arguments passed over
    dbus are valid.
  + fix a major issue with many options never being changed
  + implement various dbus methods that were missing until there,
    so that the old authentication dialog never appears.
  + add more fine-grained PolicyKit policies.
  This is actually needed for bnc#439286.
- Update system-config-printer-policykit.patch to match the
  cups-pk-helper update.
- Drop cups-pk-helper-acceptjobs.patch (fixed in 0.0.3).
- Add system-config-printer-more-checks.patch, to avoid a few
  uncaught exceptions.
* Tue Oct 28 2008 vuntz@novell.com
- Add system-config-printer-prefill-name-descr.patch to prefill
  name and description of new printers. Fix bnc#433633.
* Mon Oct 27 2008 vuntz@novell.com
- Add cups-pk-helper-acceptjobs.patch to make cups-pk-helper
  correctly handle AcceptJobs requests. This is essential to have
  new printers configured with system-config-printer working.
  Fix bnc#433634.
- Add system-config-printer-hide-my-default-printer.patch to hide
  my-default-printer from the menus. Note that
  system-config-printer already provides this functionality.
- Update system-config-printer-policykit.patch so that we don't
  show the old password prompt after changing something in a
  printer.
- Obsoletes gnome-cups-manager. No Provides, since it's not the
  same application...
* Thu Oct 23 2008 vuntz@novell.com
- Add system-config-printer-cups-autoconfig-notifications.patch.
  We display notifications for printers automatically configured
  by cups-autoconfig. This is the missing piece for dropping
  gnome-volume-manager.
* Fri Oct 17 2008 vuntz@novell.com
- Update to version 1.0.8:
  + Handle IPP_FORBIDDEN.
  + Use modelName from custom PPD to suggest name for new printer.
  + Avoid display problem with installable options.
  + Better matching for Lexmark printers.
  + Catch exceptions from advanced server settings dialog.
  + Added some missing OpenPrinting query fields.
  + Jockey support added.
  + Updated translations.
  (summary of changes taken from the Fedora package)
- Remove system-config-printer-forbidden.patch: fixed upstream.
- Add pysmbc-bnc433994-crash.patch to potentially fix a crash when
  browsing smb printers. Should fix bnc#433994.
- Add system-config-printer-git1.0.x.patch to include fixes from
  the 1.0.x branch. This fixes some crashes, and some SMB
  authentication issues. Should fix bnc#433992.
- Add system-config-printer-git1.0.x-po.patch to include updated
  translations from the 1.0.x branch.
- Update system-config-printer-icon-brp-friendly.patch.
* Thu Oct 16 2008 vuntz@novell.com
- Add more categories to my-default-printer.desktop and
  system-config-printer.desktop so that they appear in the control
  center. Fix bnc#433605.
* Fri Oct  3 2008 vuntz@novell.com
- Use %%{py_sitedir} instead of %%{_libdir}/python*/site-packages
* Fri Sep 26 2008 vuntz@novell.com
- Implement fate#4161 and fate#4162:
  + add cups-pk-helper, which is a PolicyKit helper implementing
    some parts of the API exposed by pycups.
  + add system-config-printer-policykit.patch that adds a "backend"
    for system-config-printer to use cups-pk-helper to do the CUPS
    calls.
- It's been discussed a bit with upstream, but no agreement was
  reached on this so far. The patch is not intrusive, so it's the
  best solution right now. I'll try to push it again upstream.
* Wed Sep 17 2008 vuntz@suse.de
- Copy the printer icon from gnome-icon-theme and use it as
  system-config-printer in all desktop files. Add
  system-config-printer-icon-brp-friendly.patch for this.
- Clean up packaging, and use fdupes.
* Wed Sep 10 2008 vuntz@suse.de
- Push to Factory.
* Fri Sep  5 2008 vuntz@novell.com
- Add missing system-config-printer-forbidden.patch.
- Add system-config-printer-install-python.patch to install python
  files where they should live. Also fixes the issue where the
  programs couldn't be run (because they were not +x).
* Fri Sep  5 2008 vuntz@novell.com
- Update to version 1.0.7.
  + See ChangeLog for details.
- Update pycups to 1.9.42 and pysmbc to 1.0.5.
- Remove pysmbc-debug.patch (fixed upstream) and take
  system-config-printer-forbidden.patch from Fedora package.
* Wed Aug 27 2008 vuntz@novell.com
- Update to version 1.0.6.
  + See ChangeLog for details.
* Wed Jul 30 2008 vuntz@novell.com
- Import package, based on the one from fedora and one the one on
  from home:chrismrivera in the build service.
